.. _Mahdi Moqri: https://github.com/moqri
.. _Martin Perez-Guevara: https://github.com/MartinPerez
.. _Seth Paulson: https://github.com/sarudak

.. _Dayoon Kwon: https://scholar.google.com/citations?user=5L9djqsAAAAJ&hl=en
.. _Albert Ying: https://scholar.google.com/citations?user=JS7AdkcAAAAJ&hl=zh-CN

